@@ -69,7 +69,7 @@ class Exceptions:
 
 class CloudHSMClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html)
     """
 
@@ -87,7 +87,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#add_tags_to_resource)
         """
 
@@ -95,7 +95,7 @@ class CloudHSMClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#can_paginate)
         """
 
@@ -103,7 +103,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hapg)
         """
 
@@ -114,25 +114,25 @@ class CloudHSMClient(BaseClient):
         SshKey: str,
         IamRoleArn: str,
         SubscriptionType: Literal["PRODUCTION"],
-        EniIp: str = None,
-        ExternalId: str = None,
-        ClientToken: str = None,
-        SyslogIp: str = None
+        EniIp: str = ...,
+        ExternalId: str = ...,
+        ClientToken: str = ...,
+        SyslogIp: str = ...
     ) -> CreateHsmResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hsm)
         """
 
     def create_luna_client(
-        self, *, Certificate: str, Label: str = None
+        self, *, Certificate: str, Label: str = ...
     ) -> CreateLunaClientResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_luna_client)
         """
 
@@ -140,7 +140,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hapg)
         """
 
@@ -148,7 +148,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hsm)
         """
 
@@ -156,7 +156,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_luna_client)
         """
 
@@ -164,41 +164,41 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hapg)
         """
 
     def describe_hsm(
-        self, *, HsmArn: str = None, HsmSerialNumber: str = None
+        self, *, HsmArn: str = ..., HsmSerialNumber: str = ...
     ) -> DescribeHsmResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hsm)
         """
 
     def describe_luna_client(
-        self, *, ClientArn: str = None, CertificateFingerprint: str = None
+        self, *, ClientArn: str = ..., CertificateFingerprint: str = ...
     ) -> DescribeLunaClientResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_luna_client)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#generate_presigned_url)
         """
 
@@ -208,7 +208,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#get_config)
         """
 
@@ -216,31 +216,31 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_available_zones)
         """
 
-    def list_hapgs(self, *, NextToken: str = None) -> ListHapgsResponseTypeDef:
+    def list_hapgs(self, *, NextToken: str = ...) -> ListHapgsResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hapgs)
         """
 
-    def list_hsms(self, *, NextToken: str = None) -> ListHsmsResponseTypeDef:
+    def list_hsms(self, *, NextToken: str = ...) -> ListHsmsResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hsms)
         """
 
-    def list_luna_clients(self, *, NextToken: str = None) -> ListLunaClientsResponseTypeDef:
+    def list_luna_clients(self, *, NextToken: str = ...) -> ListLunaClientsResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_luna_clients)
         """
 
@@ -248,17 +248,17 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_tags_for_resource)
         """
 
     def modify_hapg(
-        self, *, HapgArn: str, Label: str = None, PartitionSerialList: Sequence[str] = None
+        self, *, HapgArn: str, Label: str = ..., PartitionSerialList: Sequence[str] = ...
     ) -> ModifyHapgResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hapg)
         """
 
@@ -266,16 +266,16 @@ class CloudHSMClient(BaseClient):
         self,
         *,
         HsmArn: str,
-        SubnetId: str = None,
-        EniIp: str = None,
-        IamRoleArn: str = None,
-        ExternalId: str = None,
-        SyslogIp: str = None
+        SubnetId: str = ...,
+        EniIp: str = ...,
+        IamRoleArn: str = ...,
+        ExternalId: str = ...,
+        SyslogIp: str = ...
     ) -> ModifyHsmResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hsm)
         """
 
@@ -285,7 +285,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_luna_client)
         """
 
@@ -295,21 +295,21 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#remove_tags_from_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hapgs"]) -> ListHapgsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhapgspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hsms"]) -> ListHsmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhsmspaginator)
         """
 
@@ -318,6 +318,6 @@ class CloudHSMClient(BaseClient):
         self, operation_name: Literal["list_luna_clients"]
     ) -> ListLunaClientsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listlunaclientspaginator)
         """
